==> cppad-20110101.3.gpl.tgz: cppad-20110101.3/doc/_whats_new_10_xml.js <==
var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'appendix.xml',
'whats_new.xml',
'whats_new_10.xml'
];
var list_down3 = [
'install.xml',
'introduction.xml',
'ad.xml',
'adfun.xml',
'library.xml',
'cppad_ipopt_nlp.xml',
'example.xml',
'configure.xml',
'appendix.xml'
];
var list_down2 = [
'faq.xml',
'speed.xml',
'theory.xml',
'glossary.xml',
'bib.xml',
'bugs.xml',
'wishlist.xml',
'whats_new.xml',
'include_deprecated.xml',
'license.xml'
];
var list_down1 = [
'whats_new_10.xml',
'whats_new_09.xml',
'whats_new_08.xml',
'whats_new_07.xml',
'whats_new_06.xml',
'whats_new_05.xml',
'whats_new_04.xml',
'whats_new_03.xml'
];
var list_current0 = [
'whats_new_10.xml#Introduction',
'whats_new_10.xml#12-31',
'whats_new_10.xml#11-27',
'whats_new_10.xml#09-26',
'whats_new_10.xml#09-22',
'whats_new_10.xml#08-21',
'whats_new_10.xml#07-14',
'whats_new_10.xml#07-11',
'whats_new_10.xml#06-01',
'whats_new_10.xml#04-28',
'whats_new_10.xml#04-26',
'whats_new_10.xml#04-24',
'whats_new_10.xml#04-01',
'whats_new_10.xml#03-11',
'whats_new_10.xml#03-10',
'whats_new_10.xml#03-09',
'whats_new_10.xml#03-03',
'whats_new_10.xml#02-11',
'whats_new_10.xml#02-08',
'whats_new_10.xml#02-06',
'whats_new_10.xml#02-05',
'whats_new_10.xml#02-03',
'whats_new_10.xml#01-26',
'whats_new_10.xml#01-24',
'whats_new_10.xml#01-23',
'whats_new_10.xml#01-20',
'whats_new_10.xml#01-18',
'whats_new_10.xml#01-04'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down3(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down3[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}

==> cppad-20130000.3.gpl.tgz: cppad-20130000.3/doc/_whats_new_10_xml.js <==
var list_across0 = [
'_contents_xml.htm',
'_reference.xml',
'_index.xml',
'_search_xml.htm',
'_external.xml'
];
var list_up0 = [
'cppad.xml',
'appendix.xml',
'whats_new.xml',
'whats_new_10.xml'
];
var list_down3 = [
'install.xml',
'introduction.xml',
'ad.xml',
'adfun.xml',
'preprocessor.xml',
'multi_thread.xml',
'library.xml',
'ipopt_solve.xml',
'example.xml',
'speed.xml',
'appendix.xml'
];
var list_down2 = [
'faq.xml',
'theory.xml',
'glossary.xml',
'bib.xml',
'bugs.xml',
'wishlist.xml',
'whats_new.xml',
'deprecated.xml',
'compare_c.xml',
'license.xml'
];
var list_down1 = [
'whats_new_12.xml',
'whats_new_11.xml',
'whats_new_10.xml',
'whats_new_09.xml',
'whats_new_08.xml',
'whats_new_07.xml',
'whats_new_06.xml',
'whats_new_05.xml',
'whats_new_04.xml',
'whats_new_03.xml'
];
var list_current0 = [
'whats_new_10.xml#Introduction',
'whats_new_10.xml#12-31',
'whats_new_10.xml#11-27',
'whats_new_10.xml#09-26',
'whats_new_10.xml#09-22',
'whats_new_10.xml#08-21',
'whats_new_10.xml#07-14',
'whats_new_10.xml#07-11',
'whats_new_10.xml#06-01',
'whats_new_10.xml#04-28',
'whats_new_10.xml#04-26',
'whats_new_10.xml#04-24',
'whats_new_10.xml#04-01',
'whats_new_10.xml#03-11',
'whats_new_10.xml#03-10',
'whats_new_10.xml#03-09',
'whats_new_10.xml#03-03',
'whats_new_10.xml#02-11',
'whats_new_10.xml#02-08',
'whats_new_10.xml#02-06',
'whats_new_10.xml#02-05',
'whats_new_10.xml#02-03',
'whats_new_10.xml#01-26',
'whats_new_10.xml#01-24',
'whats_new_10.xml#01-23',
'whats_new_10.xml#01-20',
'whats_new_10.xml#01-18',
'whats_new_10.xml#01-04'
];
function choose_across0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_across0[index-1];
}
function choose_up0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_up0[index-1];
}
function choose_down3(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down3[index-1];
}
function choose_down2(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down2[index-1];
}
function choose_down1(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down1[index-1];
}
function choose_down0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_down0[index-1];
}
function choose_current0(item)
{	var index          = item.selectedIndex;
	item.selectedIndex = 0;
	if(index > 0)
		document.location = list_current0[index-1];
}
